pywurfl.exceptions

Package pywurfl :: Module exceptions |
[hide private]
[frames] | no frames]

# Source Code for Module pywurfl.exceptions

     1  # pywurfl Exceptions
     2  # Copyright (C) 2006-2008 Armand Lynch
     3  #
     4  # This library is free software; you can redistribute it and/or modify it
     5  # under the terms of the GNU Lesser General Public License as published by the
     6  # Free Software Foundation; either version 2.1 of the License, or (at your
     7  # option) any later version.
     8  #
     9  # This library is distributed in the hope that it will be useful, but WITHOUT
    10  # ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
    11  # FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
    12  # details.
    13  #
    14  # You should have received a copy of the GNU Lesser General Public License
    15  # along with this library; if not, write to the Free Software Foundation, Inc.,
    16  # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
    17  #
    18  # Armand Lynch <lyncha@users.sourceforge.net>
    19
    20  __doc__ = \
    21  """
    22  Exception Classes
    23  """
    24
    25  __author__ = "Armand Lynch <lyncha@users.sourceforge.net>"
    26  __copyright__ = "Copyright 2006-2008, Armand Lynch"
    27  __license__ = "LGPL"
    28  __url__ = "http://celljam.net/"
    29
    30
    31 -class WURFLException(Exception):
    32      """
    33      pywurfl base exception class.
    34      """
    35      pass
    36
    37
    38 -class ExistsException(WURFLException):
    39      """
    40      General exception class
    41
    42      Raised when an operation should not continue if an object exists.
    43      """
    44
    45
    46 -class DeviceNotFound(WURFLException):
    47      """
    48      Device Not Found exception class
    49
    50      Raised when pywurfl cannot find a device by using either select_*
    51      API functions.
    52      """
    53      pass
    54
    55
    56 -class ActualDeviceRootNotFound(WURFLException):
    57      """
    58      Actual Device Root Not Found exception class
    59
    60      Raised when pywurfl cannot find an actual device root by using either
    61      select_* API functions.
    62      """
    63      pass
    64